# City of Grand Rapids Socrata Open Data
This package includes libraries of functions create, update, and load data from The City of Grand Rapids instance of Socrata data analytics software.
#### Methods Overview
* Create Datasets
* Update Datasets
* Pull Data by Date Range
* Delete Data by Date Range